<?php

if ($argc < 2) {
    echo "Usage: $argv[0] <CCU IP>".PHP_EOL;
    exit (1);
}
$ccuip = $argv[1];

$hg = new Homegear\Homegear();

echo "Using Homegear script engine (".$hg->getVersion().")".PHP_EOL;

$data=
"!# devices.fn hm2mqtt
!#
!# Dieses Homematic-Script gibt eine Liste aller Geraete/Kanaele im JSON Format aus
!#
!# 3'2013-4'2017 hobbyquaker https://github.com/hobbyquaker
!#

string sDevId;
string sChnId;

Write('{');

boolean dFirst = true;

foreach (sDevId, root.Devices().EnumUsedIDs()) {

    object oDevice   = dom.GetObject(sDevId);
    boolean bDevReady = oDevice.ReadyConfig();

    if (bDevReady) {

        if (dFirst) {
          dFirst = false;
        } else {
          WriteLine(',');
        }

        Write('\"' # oDevice.Address() # '\":\"');
        WriteURL(oDevice.Name());
        Write('\"');

        foreach(sChnId, oDevice.Channels()) {
        	object oChannel = dom.GetObject(sChnId);
            WriteLine(',');
          	Write('\"' # oChannel.Address() # '\":\"');
        	WriteURL(oChannel.Name());
        	Write('\"');
        }

    }
}

Write('}');
";

$url = 'http://'.$ccuip.':8181/rega.exe';

// use key 'http' even if you send the request to https://...
$options = array(
    'http' => array(
        'header'  => "Content-type: application/x-www-form-urlencoded\r\n",
        'method'  => 'POST',
        'content' => $data
    )
);
$context  = stream_context_create($options);
$result = file_get_contents($url, false, $context);
if ($result === FALSE) {
    echo "Could not get device names from $url".PHP_EOL;
    exit(1);
}

# Remove XML footer
$pos = strrpos($result, "<xml>");
$result = substr($result, 0, $pos);

# Now decode the JSON string to associative array
$devicenames = json_decode($result, true);

//var_dump($devicenames);

foreach ($devicenames as $serialno => $name) {
    //echo "Searching for ".$serialno.PHP_EOL;
    $devices = $hg->getPeerId(1, $serialno );
    if (count($devices) == 1) {
    $name = urldecode($name);
    $peerId = $devices[0];
    echo "Found Homegear peer id ".$peerId." with ".$serialno." -> Setting name to ".$name.PHP_EOL;
    $hg->setName($peerId, $name);
    }
    elseif (count($devices) > 1) {
    echo "Multiple Homegear devices with the same serial number found: ".$serialno.PP_EOL;
    }
}


exit(0);

?>
